RdRand

Struct RdRand 

pub struct RdRand(/* private fields */);
A cryptographically secure statistically uniform, non-periodic and non-deterministic random bit generator.

Note that this generator may be implemented using a deterministic algorithm that is reseeded routinely from a non-deterministic entropy source to achieve the desirable properties.

This generator is a viable replacement to any generator, however, since nobody has audited this hardware implementation yet, the usual disclaimers as to their suitability apply.

It is potentially faster than OsRng, but is only supported by more recent architectures such as Intel Ivy Bridge and AMD Zen.

Implementations

Source

impl RdRand

pub fn new() -> Result<Self, ErrorCode>

Create a new instance of the random number generator.

This constructor checks whether the CPU the program is running on supports the instruction necessary for this generator to operate. If the instruction is not supported, an error is returned.

pub unsafe fn new_unchecked() -> Self

Create a new instance of the random number generator.

Safety

This constructor is unsafe because it doesn’t check that the CPU supports the instruction, but devolves this responsibility to the caller.