RdSeed

Struct RdSeed 

pub struct RdSeed(/* private fields */);
A cryptographically secure non-deterministic random bit generator.

This generator produces high-entropy output and is suited to seed other pseudo-random generators.

This instruction is only supported by recent architectures such as Intel Broadwell, AMD Zen, and as an optional feature on AArch64 Armv8.1 and newer.

This generator is not intended for general random number generation purposes and should be used to seed other generators implementing rand_core::SeedableRng.

Implementations

Source

impl RdSeed

pub fn new() -> Result<Self, ErrorCode>

Create a new instance of the random number generator.

This constructor checks whether the CPU the program is running on supports the instruction necessary for this generator to operate. If the instruction is not supported, an error is returned.

pub unsafe fn new_unchecked() -> Self

Create a new instance of the random number generator.

Safety

This constructor is unsafe because it doesn’t check that the CPU supports the instruction, but devolves this responsibility to the caller.